@@ -226,7 +226,17 @@ class ComponentAPI:
         self, 
         carrier_unique_id: str,
         page: int = 1,
-        limit: int = 50
+        limit: int = 50,
+        component_unique_id: Optional[str] = None,
+        component_name: Optional[str] = None,
+        component_version: Optional[str] = None,
+        status: Optional[str] = None,
+        asset_category: Optional[str] = None,
+        asset_type: Optional[str] = None,
+        vendor: Optional[str] = None,
+        ecosystem: Optional[str] = None,
+        repository: Optional[str] = None,
+        package_type: Optional[str] = None
     ) -> Dict[str, Any]:
         """
         获取载体下的软件成分列表
@@ -235,15 +245,92 @@ class ComponentAPI:
             carrier_unique_id: 载体唯一ID
             page: 页码
             limit: 每页条数
+            component_unique_id: 成分唯一ID
+            component_name: 成分名称
+            component_version: 成分版本
+            status: 状态
+            asset_category: 资产类别
+            asset_type: 资产类型
+            vendor: 供应商
+            ecosystem: 生态系统
+            repository: 仓库
+            package_type: 包类型
             
         Returns:
             成分列表
         """
+        # 验证必填参数
+        if not carrier_unique_id or not isinstance(carrier_unique_id, str):
+            raise SARMValidationError("carrier_unique_id 是必填参数且必须是字符串类型")
+        
+        if carrier_unique_id.strip() == '':
+            raise SARMValidationError("carrier_unique_id 不能为空字符串")
+        
+        # 验证分页参数
+        if not isinstance(page, int) or page < 1:
+            raise SARMValidationError("页码必须是大于0的整数")
+        
+        if not isinstance(limit, int) or limit < 1 or limit > 1000:
+            raise SARMValidationError("每页条数必须是1-1000之间的整数")
+        
+        # 构建请求数据
         data = {
             "carrier_unique_id": carrier_unique_id,
             "page": page,
             "limit": limit
         }
+        
+        # 添加可选查询参数
+        if component_unique_id is not None:
+            if not isinstance(component_unique_id, str):
+                raise SARMValidationError("component_unique_id 必须是字符串类型")
+            data["component_unique_id"] = component_unique_id
+            
+        if component_name is not None:
+            if not isinstance(component_name, str):
+                raise SARMValidationError("component_name 必须是字符串类型")
+            data["component_name"] = component_name
+            
+        if component_version is not None:
+            if not isinstance(component_version, str):
+                raise SARMValidationError("component_version 必须是字符串类型")
+            data["component_version"] = component_version
+            
+        if status is not None:
+            if not isinstance(status, str):
+                raise SARMValidationError("status 必须是字符串类型")
+            data["status"] = status
+            
+        if asset_category is not None:
+            if not isinstance(asset_category, str):
+                raise SARMValidationError("asset_category 必须是字符串类型")
+            data["asset_category"] = asset_category
+            
+        if asset_type is not None:
+            if not isinstance(asset_type, str):
+                raise SARMValidationError("asset_type 必须是字符串类型")
+            data["asset_type"] = asset_type
+            
+        if vendor is not None:
+            if not isinstance(vendor, str):
+                raise SARMValidationError("vendor 必须是字符串类型")
+            data["vendor"] = vendor
+            
+        if ecosystem is not None:
+            if not isinstance(ecosystem, str):
+                raise SARMValidationError("ecosystem 必须是字符串类型")
+            data["ecosystem"] = ecosystem
+            
+        if repository is not None:
+            if not isinstance(repository, str):
+                raise SARMValidationError("repository 必须是字符串类型")
+            data["repository"] = repository
+            
+        if package_type is not None:
+            if not isinstance(package_type, str):
+                raise SARMValidationError("package_type 必须是字符串类型")
+            data["package_type"] = package_type
+        
         response = self.client.post('/api/carrier/components', data=data)
         return response
         
@@ -257,22 +344,8 @@ class ComponentAPI:
         ecosystem: Optional[str] = None,
         repository: Optional[str] = None
     ) -> Dict[str, Any]:
-        """
-        获取成分唯一ID
+    
         
-        Args:
-            component_name: 应用成分名称（必需）
-            component_version: 应用成分版本（可选）
-            vendor: 资产的提供商、来源或制造商（可选）。对于开源项目，可以是基金会或主要维护者；对于自研，可以是 "Internal"。
-            ecosystem: 生态系统（可选）
-            repository: 仓库（可选）
-            
-        Returns:
-            API响应结果
-            
-        Raises:
-            SARMValidationError: 当参数验证失败时抛出
-        """
         # 验证必填参数
         if not component_name or not isinstance(component_name, str):
             raise SARMValidationError("component_name 是必填参数且必须是字符串类型")
