@@ -20,11 +20,10 @@ class OrganizeUserAPI:
     def __init__(self, client: 'SARMClient'):
         self.client = client
 
-
     def create_batch(
-        self,
-        organize_unique_id: str,
-        users: List[Dict[str, Any]]
+            self,
+            organize_unique_id: str,
+            users: List[Dict[str, Any]]
     ) -> Dict[str, Any]:
         """
         批量创建组织用户
@@ -39,13 +38,6 @@ class OrganizeUserAPI:
         if not users:
             raise SARMValidationError("用户列表不能为空")
 
-        # 验证必填字段
-        for user in users:
-            if 'password' not in user:
-                raise SARMValidationError("缺少 password 字段")
-            if 'source' not in user:
-                raise SARMValidationError("缺少 source 字段")
-
         data = {
             "organize_unique_id": organize_unique_id,
             "user_list": users
@@ -55,9 +47,9 @@ class OrganizeUserAPI:
         return response
 
     def create(
-        self,
-        organize_unique_id: str,
-        user_data: Dict[str, Any]
+            self,
+            organize_unique_id: str,
+            user_data: Dict[str, Any]
     ) -> Dict[str, Any]:
         """创建单个组织用户"""
         return self.create_batch(organize_unique_id, [user_data])
@@ -83,11 +75,11 @@ class OrganizeUserAPI:
         return self.delete_batch([user_id])
 
     def get_list(
-        self,
-        organize_unique_id: str,
-        page: int = 1,
-        limit: int = 10,
-        user_info: Optional[Dict[str, Any]] = None
+            self,
+            organize_unique_id: str,
+            page: int = 1,
+            limit: int = 10,
+            user_info: Optional[Dict[str, Any]] = None
     ) -> Dict[str, Any]:
         """
         获取组织用户列表
@@ -111,7 +103,7 @@ class OrganizeUserAPI:
         response = self.client.post('/api/organize_user/list', data=data)
         return response
 
-    def update_batch(self, organizeUniqueId: str, users: List[Dict[str, Any]]) -> Dict[str, Any]:
+    def update_batch(self, users: List[Dict[str, Any]]) -> Dict[str, Any]:
         """
         批量更新组织用户
 
@@ -132,20 +124,15 @@ class OrganizeUserAPI:
                 raise SARMValidationError("缺少 organize_user_name 字段")
             if 'organize_user_enterprise_email' not in user:
                 raise SARMValidationError("缺少 organize_user_enterprise_email 字段")
-            if 'password' not in user:
-                raise SARMValidationError("缺少 password 字段")
-        data = {
-            "organize_unique_id": organizeUniqueId,
-            "user_list": users
-        }
+        data = users
         response = self.client.post('/api/organize_user/update', data=data)
         return response
 
-    def update(self,  organizeUniqueId: str,user_data: Dict[str, Any]) -> Dict[str, Any]:
+    def update(self, user_data: Dict[str, Any]) -> Dict[str, Any]:
         """更新单个组织用户"""
-        return self.update_batch(organizeUniqueId,[user_data])
-    
-    def delete_organize(self, organize_user_id: List[str]) -> Dict[str, Any]:
+        return self.update_batch([user_data])
+
+    def delete_organize(self, organize_user_id: List[str]):
         """删除组织用户的组织关联"""
         response = self.client.post('/api/organize_user/delete_organize', data=organize_user_id)
-        return response
\ No newline at end of file
+        return response
