@@ -39,7 +39,7 @@ class SARMClient:
         self,
         base_url: str,
         token: str,
-        factory_log_id,
+        factory_log_id: str = "",
         timeout: int = 30,
         max_retries: int = 3,
         retry_delay: float = 1.0
@@ -261,7 +261,7 @@ class SARMClient:
     def post(
         self,
         endpoint: str,
-        data: Optional[Union[Dict[str, Any], List[Dict[str, Any]]]] = None,
+        data: Optional[Union[Dict[str, Any], List[Dict[str, Any]], List[str]]] = None,
         params: Optional[Dict[str, Any]] = None,
         execute_release: Optional[bool] = None
     ) -> Dict[str, Any]:
