@@ -308,7 +308,7 @@ class BasePlugin(ABC):
                     )
                     break
 
-            if buffer:
+            if buffer and not is_test_mode:
                 self.load(buffer)
 
             self.logger.info("插件执行完毕。")
